@@ -22,9 +22,9 @@ QRangeSlider.
 
 from typing import Generic, TypeVar
 
-from ..qtcompat import QtGui
-from ..qtcompat.QtCore import QEvent, QPoint, QPointF, QRect, Qt, Signal
-from ..qtcompat.QtWidgets import (
+from qtpy import QtGui
+from qtpy.QtCore import QEvent, QPoint, QPointF, QRect, Qt, Signal
+from qtpy.QtWidgets import (
     QApplication,
     QSlider,
     QStyle,
@@ -40,13 +40,13 @@ SC_GROOVE = QStyle.SubControl.SC_SliderGroove
 SC_TICKMARKS = QStyle.SubControl.SC_SliderTickmarks
 
 CC_SLIDER = QStyle.ComplexControl.CC_Slider
-QOVERFLOW = 2 ** 31 - 1
+QOVERFLOW = 2**31 - 1
 
 
 class _GenericSlider(QSlider, Generic[_T]):
-    valueChanged = Signal(float)
-    sliderMoved = Signal(float)
-    rangeChanged = Signal(float, float)
+    _fvalueChanged = Signal(float)
+    _fsliderMoved = Signal(float)
+    _frangeChanged = Signal(float, float)
 
     MAX_DISPLAY = 5000
 
@@ -74,6 +74,10 @@ class _GenericSlider(QSlider, Generic[_T]):
         self._control_fraction = 0.04
 
         super().__init__(*args, **kwargs)
+        self.valueChanged = self._fvalueChanged
+        self.sliderMoved = self._fsliderMoved
+        self.rangeChanged = self._frangeChanged
+
         self.setAttribute(Qt.WidgetAttribute.WA_Hover)
 
     # ###############  QtOverrides  #######################
